#
# spec file for package trurl
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2023-2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           trurl
Version:        0.14
Release:        1.1
Summary:        Command line tool for URL parsing and manipulation
License:        MIT
Group:          Productivity/Networking/Web/Utilities
#Git-Clone:     https://github.com/curl/trurl.git
URL:            https://curl.se/trurl
Source:         https://github.com/curl/trurl/archive/refs/tags/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  pkgconfig(libcurl) >= 7.62.0

%description
A CLI tool that parses and manipulates URLs, designed to help
shell script authors everywhere.

%prep
%setup -q -n %{name}-%{name}-%{version}

%build
%make_build PREFIX=%{_prefix}

%install
make PREFIX=%{_prefix} DESTDIR=%{buildroot} install

%check
make test

%files
%license COPYING
%doc README.md RELEASE-NOTES
%{_bindir}/trurl
%{_mandir}/man1/trurl.1%{?ext_man}

%changelog
* Mon Jul 29 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.14
  * remove a suprious trailing newline from a warning.
  * trurl.1: document the exit codes.
  * add "strict:" as prefix to a get component.
  * casecompare: a strncasemp replacement.
  * support conditionally set scheme.
* Wed May 15 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.13
  * Free allocated pointer on OOM error.
  * short options need no space separation for the argument anymore
  * trurl.1: use present tense.
  * trurl: only append the first iterate loop.
  * fix Coverity nits.
* Thu Apr 18 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.12
  * This is the same as 0.11 but with the version string set
    correctly.
* Thu Apr 18 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.11
  * Added UTF-8 detection to test runner.
  * use of free() instead of curl_free().
  * output the list of components correctly in the help output.
  * if query is not updated, leave it untouched.
  * expand the warning on "internal problem".
  * error when using an unrecognized URL component.
* Wed Feb 21 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.10
  Changes:
  * add --replace
  Bugfixes:
  * fixed buffer overflows on %%00 use
  * enable more C compiler warnings and fix them
* Tue Oct 31 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9
  Changes:
  * add --as-idn and punycode to IDN conversion
  * add --curl to only count as valid URLs supported by libcurl
  Bugfixes:
  * accept * as a trim name to trim a literal asterisk name
  * format null as \u0000 for --json
  * run --trim query before --append query
- Drop patch
  * trurl-disable-broken-tests.patch (fixed by upstream)
* Fri Sep 22 2023 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * trurl-disable-broken-tests.patch
* Sat Jun 17 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8
  Changes:
  * add --urlencode
  Bugfixes:
  * --json/--get: .[].parts and {component} should be urldecoded
    not encoded
  * tests: use empty file instead of /dev/null
  * typos in manpage
  * Makefile: Allow CFLAGS to be appendable
  * Makefile: be explicit in C standard to use
* Tue Jun 13 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 0.7
  * Changes:
  - -default-port to ask for the default to be used if not present
  - -keep-port to ask for the port number to be there even if default
  - -no-guess-scheme option to disable scheme guessing
  - -punycode to ask for the punycode version in output
  * Bugfixes:
  - -help returns 0 instead of 1
  - -json: print empty arrays
  - -redirect: don't silently ignore failed redirections.
    refuse setting same component in --set as --iterate
    restructure the JSON output object
    send -h output to stdout, not stderr
* Wed Apr 26 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6
  * offer {puny:host} and {puny:url} for --get
  * provide built-with libcurl version info for --version
  * support for skipping tests
  * test.py replaced test.pl
  * test.py supports --with-valgrind
  * tests.json: extended and updated
  * URL-QUIRKS: specify if they are build-time or run-time
    requirements
* Mon Apr 17 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5
  Changes since previous release
  * --get supports variables in [brackets] as well
  * --get {query-all:key} outputs all values for 'key' in the
    query
  * switched to test.py for tests
  * --iterate is a new option.
  Bugfixes since previous release
  * handle %%00 sequences in {query:key} output
  * support reading URL from a file without a newline
  * fixed a json memory-leak
* Mon Apr 10 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4
  Changes
  * --get supports showing {query:key}
  * --json outputs query pairs under "params"
  * -a is an --append shortcut
  * add --query-separator
  * add --sort-query
  Bugfixes
  * components names are lower case and case sensitive
  * fixed the json output of UTF-8 sequences
  * flush stdout after handling every URL
  * mixing --json with --get is an error
  * more test cases
  * show error messsage when component setting fails
  * support "--" end-of-options argument
  * support for building with older libcurl versions
* Thu Apr  6 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.3
  Changes
  * the set port is the same as the scheme-default, don't show
  * many more tests
  * https://curl.se/trurl is now the project's website
  * added --accept-space
  * added --trim
  Bugfixes
  * setting port to a blank now clears it
  * improved the man page
  * fix --append query when no previous query exists
  * output JSON as an array
  * provide the -h list in pure alphabetical order
  * use 0644 for the man page install
  * use Test::More inside of test.pl
  * nicer JSON tests and test output
- Drop patch:
  * trurl-manpage-fix-spurious-executable-perm-manpage.patch
- Run testsuite
* Mon Apr  3 2023 Martin Hauke <mardnh@gmx.de>
- Add patch
  * trurl-manpage-fix-spurious-executable-perm-manpage.patch
* Mon Apr  3 2023 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.2
